MatchMakerActivation.all\_input\_elements
=============================================================

.. currentmodule:: alfred3_interact.page

.. autoproperty:: MatchMakerActivation.all_input_elements
